from django.contrib import admin
from django.template.defaultfilters import linebreaksbr
from .models import Email


class EmailAdmin(admin.ModelAdmin):
    list_display = ['recipients', 'from_email', 'subject', 'date_sent', 'ok']
    list_filter = ['date_sent', 'ok']
    readonly_fields = ['from_email', 'recipients', 'subject', 'body_formatted',
                       'date_sent', 'ok']
    search_fields = ['subject', 'body', 'recipients']
    exclude = ['body']

    def has_delete_permission(self, *args, **kwargs):
        return False

    def has_add_permission(self, *args, **kwargs):
        return False

    def body_formatted(self, obj):
        return linebreaksbr(obj.body)
    body_formatted.short_description = "body"


admin.site.register(Email, EmailAdmin)



from django.db import models, migrations


class Migration(migrations.Migration):

    dependencies = [
        ('email_log', '0001_initial'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='email',
            options={
                'ordering': ('-date_sent',),
                'verbose_name_plural': 'emails',
                'verbose_name': 'email',
            },
        ),
        migrations.AlterField(
            model_name='email',
            name='from_email',
            field=models.TextField(verbose_name='from email'),
        ),
    ]



from setuptools import setup, find_packages
import email_log


setup(
    name='django-email-log',
    version=email_log.__version__,
    author='Trey Hunner',
    author_email='trey@treyhunner.com',
    description='Django email backend that logs all emails',
    long_description='\n\n'.join((
        open('README.rst').read(),
        open('CHANGES.rst').read(),
    )),
    url='https://github.com/treyhunner/django-email-log',
    license='LICENSE',
    packages=find_packages(),
    install_requires=['Django >= 1.11.0'],
    classifiers=[
        'Development Status :: 5 - Production/Stable',
        'Environment :: Web Environment',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
        'Operating System :: OS Independent',
        'Programming Language :: Python',
        'Programming Language :: Python :: 3',
        'Framework :: Django',
    ],
    tests_require=['Django >= 1.11.0'],
    include_package_data=True,
    test_suite='runtests.runtests',
)



from django.core.mail import get_connection
from django.core.mail.backends.base import BaseEmailBackend

from .conf import settings
from .models import Email


class EmailBackend(BaseEmailBackend):

    """Wrapper email backend that records all emails in a database model"""

    def __init__(self, **kwargs):
        super(EmailBackend, self).__init__(**kwargs)
        self.connection = get_connection(settings.EMAIL_LOG_BACKEND, **kwargs)

    def send_messages(self, email_messages):
        num_sent = 0
        for message in email_messages:
            recipients = '; '.join(message.to)
            email = Email.objects.create(
                from_email=message.from_email,
                recipients=recipients,
                subject=message.subject,
                body=message.body,
            )
            message.connection = self.connection
            num_sent += message.send()
            if num_sent > 0:
                email.ok = True
                email.save()
        return num_sent
